@@ -1,3 +1,4 @@
+import os
 from unittest.mock import mock_open, patch
 
 from django.core.management import call_command
@@ -16,6 +17,7 @@ from .assets.generated_protobuf_files import (
 )
 
 
+@patch.dict(os.environ, {"DJANGO_SETTINGS_MODULE": "myproject.settings"})
 class TestProtoGeneration(TestCase):
     def test_generate_one_model(self):
         self.maxDiff = None
@@ -28,7 +30,7 @@ class TestProtoGeneration(TestCase):
         with patch("builtins.open", mock_open()) as m:
             call_command("generateproto", *args, **opts)
 
-        m.assert_called_once_with("proto/unittestmodel.proto", "w")
+        m.assert_called_once_with("proto/unittestmodel.proto", "r+")
         handle = m()
 
         called_with_data = handle.write.call_args[0][0]
@@ -88,7 +90,7 @@ class TestProtoGeneration(TestCase):
 
         # this is done to avoid error on different absolute path
         assert m.mock_calls[0].args[0].endswith("fakeapp/grpc/fakeapp.proto")
-        assert m.mock_calls[0].args[1] == "w"
+        assert m.mock_calls[0].args[1] == "r+"
 
         handle = m()
 
@@ -105,7 +107,7 @@ class TestProtoGeneration(TestCase):
 
         # this is done to avoid error on different absolute path
         assert m.mock_calls[0].args[0].endswith("fakeapp/grpc/fakeapp.proto")
-        assert m.mock_calls[0].args[1] == "w"
+        assert m.mock_calls[0].args[1] == "r+"
         handle = m()
 
         called_with_data = handle.write.call_args[0][0]
@@ -120,7 +122,7 @@ class TestProtoGeneration(TestCase):
 
         # this is done to avoid error on different absolute path
         assert m.mock_calls[0].args[0].endswith("fakeapp/grpc/fakeapp.proto")
-        assert m.mock_calls[0].args[1] == "w"
+        assert m.mock_calls[0].args[1] == "r+"
 
         handle = m()
 
@@ -137,7 +139,7 @@ class TestProtoGeneration(TestCase):
 
         # this is done to avoid error on different absolute path
         assert m.mock_calls[0].args[0].endswith("fakeapp/grpc/fakeapp.proto")
-        assert m.mock_calls[0].args[1] == "w"
+        assert m.mock_calls[0].args[1] == "r+"
 
         handle = m()
 
@@ -153,7 +155,7 @@ class TestProtoGeneration(TestCase):
 
         # this is done to avoid error on different absolute path
         assert m.mock_calls[0].args[0].endswith("fakeapp/grpc/fakeapp.proto")
-        assert m.mock_calls[0].args[1] == "w"
+        assert m.mock_calls[0].args[1] == "r+"
 
         handle = m()
 
@@ -173,7 +175,7 @@ class TestProtoGeneration(TestCase):
 
         # this is done to avoid error on different absolute path
         assert m.mock_calls[0].args[0].endswith("fakeapp/grpc/fakeapp.proto")
-        assert m.mock_calls[0].args[1] == "w"
+        assert m.mock_calls[0].args[1] == "r+"
 
         handle = m()
 
